@@ -1,10 +1,5 @@
 from django.contrib import admin
-from .models import Activity, Actor, InstalacaoAtivo
-
-
-@admin.register(InstalacaoAtivo)
-class InstalacaoAtivoAdmin(admin.ModelAdmin):
-    list_display = ['id', 'comments']
+from .models import Activity, Actor, OldDevice
 
 
 @admin.register(Actor)
@@ -15,3 +10,8 @@ class ActorAdmin(admin.ModelAdmin):
 @admin.register(Activity)
 class ActivityAdmin(admin.ModelAdmin):
     list_display = ['id', 'device']
+
+
+@admin.register(OldDevice)
+class OldDevice(admin.ModelAdmin):
+    list_display = ['id']
