@@ -1,5 +1,7 @@
 from django.db import models
 from datetime import date
+
+from django.db.models.deletion import CASCADE
 from dcim.models import Device
 
 
@@ -8,9 +10,9 @@ class ActivityOptions(models.TextChoices):
     REMOCAO = 'RE', 'Remoção'
 
 
-class InstalacaoAtivo(models.Model):
+""" class InstalacaoAtivo(models.Model):
 
-    comments = models.CharField(max_length=200)
+    comments = models.CharField(max_length=200) # comments
     atv_data = models.DateField(default=date.today)
     reg_atv = models.DateTimeField(auto_now_add=True)
     actor_id = models.ManyToManyField('Actor')
@@ -22,6 +24,7 @@ class InstalacaoAtivo(models.Model):
 
     def __str__(self):
         return self.comments
+ """
 
 
 class Actor(models.Model):
@@ -38,12 +41,20 @@ class Actor(models.Model):
 class Activity(models.Model):
     device = models.ForeignKey(
         to='dcim.Device',
-        on_delete=models.PROTECT
+        on_delete=models.CASCADE
     )
     actor = models.ManyToManyField(Actor)
-    type = models.CharField(max_length=50, null=False, blank=False)
+    type = models.CharField(
+        max_length=2,
+        choices=ActivityOptions.choices,
+        default=ActivityOptions.INSTALACAO,
+    )
     when = models.DateField(default=date.today)
     description = models.TextField(max_length=255, null=True, blank=True)
 
     def __str__(self):
         return self.description
+
+
+class OldDevice(models.Model):
+    activity = models.OneToOneField(Activity, on_delete=CASCADE)
