@@ -1,6 +1,6 @@
 from extras.plugins import PluginTemplateExtension
 
-from .models import Instalacaoativo
+from .models import InstalacaoAtivo
 
 
 class SiteDnsCount(PluginTemplateExtension):
@@ -13,7 +13,7 @@ class SiteDnsCount(PluginTemplateExtension):
 
     def right_page(self):
         return self.render('conectividadeapp/inc/conectividadeapp_count.html', extra_context={
-            're_count': Instalacaoativo.objects.count(),
+            're_count': InstalacaoAtivo.objects.count(),
         })
 
 
