@@ -1,5 +1,4 @@
 from django.shortcuts import render, redirect, get_object_or_404
-from .models import InstalacaoAtivo
 from django.http import HttpResponse
 import datetime
 from django.views.generic import View
@@ -7,15 +6,11 @@ from dcim.models import Device
 
 
 class ListConectividadeView(View):
-    """
-    List all reg in the database.
-    """
+
     def get(self, request):
 
-        rg = InstalacaoAtivo.objects.all()
-        dv = Device.objects.all()
-        return render(request, 'conectividadeapp/listagem.html', {
-            'registro': rg,
-            'device': dv,
+        device = Device.objects.all()
 
+        return render(request, 'conectividadeapp/listagem.html', {
+            'Device': device,
         })
